@@ -1,5 +1,5 @@
 ## File Name: ANSI_create_table_check_variable_values.R
-## File Version: 0.03
+## File Version: 0.041
 
 
 ANSI_create_table_check_variable_values <- function(variable, values, dat)
@@ -9,7 +9,7 @@ ANSI_create_table_check_variable_values <- function(variable, values, dat)
         g1 <- paste0("The following values of variable '", variable,
                 "' are missing: ")
         g2 <- paste0(v1, collapse=" ")
-        stop( paste0(g1, g2, "\n"))
+        warning( paste0(g1, g2, "\n"))
     }
 
 }
