@@ -1,9 +1,10 @@
 ## File Name: load.Rdata.R
-## File Version: 1.04
+## File Version: 1.05
 
 #****************************************
 # load R data objects globally
-load.Rdata <- function( filename, objname ){
+load.Rdata <- function( filename, objname )
+{
     d1 <- load( filename )
     eval( parse( text=paste( objname,  "<<- ", d1  ) ) )
 }
