@@ -1,5 +1,5 @@
 ## File Name: mice_imputation_tricube_pmm_match.R
-## File Version: 0.02
+## File Version: 0.04
 
 
 
@@ -12,7 +12,8 @@ mice_imputation_tricube_pmm_match <- function (z, yhat=yhat, y=y, donors=3,
     d <- abs(yhat - z)
     donorset <- which( rank(d, ties.method="ran") <=donors )
     s.tricube <- tricube.pmm.scale * mean( d )
-    prob.x <- unlist( sapply( d, FUN=function(dd){ ( 1- min( dd / s.tricube, 1 )^3  )^3 } ) )
+    prob.x <- unlist( sapply( d, FUN=function(dd){
+                        ( 1- min( dd / s.tricube, 1 )^3  )^3 } ) )
     # prevent the case that all weights are equal to zero
     prob.x[ donorset ] <- prob.x[donorset] + eps1
     # standardize weights to probabilities
